@@ -31,10 +31,9 @@ import html5lib
 from html5lib import treebuilders
 
 from tiddlyweb.model.tiddler import Tiddler
-from tiddlyweb.store import Store
 from tiddlyweb.serializer import Serializer
 from tiddlyweb.util import std_error_message
-from tiddlywebwiki.tiddlywiki import handle_tiddler_div
+from tiddlywebwiki.tiddlywiki import handle_tiddler_div, import_wiki
 
 from tiddlywebplugins.utils import get_store
 
@@ -60,10 +59,20 @@ def import_one(bag, url, store):
         import_plugin(bag, url, store)
     elif url.endswith('.tid'):
         import_tid_tiddler(bag, url, store)
+    elif url.endswith('.wiki'):
+        import_via_wiki(bag, url, store)
     else:
         import_tiddler(bag, url, store)
 
 
+def import_via_wiki(bag, url, store):
+    """
+    Import one wiki into bag, delegating to import_wiki code.
+    """
+    wiki = get_url(url)
+    import_wiki(store, wiki, bagname=bag)
+
+
 def import_via_recipe(bag, url, store):
     """
     Import one recipe into bag, calling import_one as needed.
@@ -89,7 +98,7 @@ def handle_recipe(url, content):
     for rule in rules:
         target = rule.split(':', 1)[1]
         target = target.lstrip().rstrip()
-        if not (target.startswith('http:') or 
+        if not (target.startswith('http:') or
                 target.startswith('https:')):
             if not '%' in target:
                 target = urllib.quote(target)
@@ -161,7 +170,8 @@ def process_tiddler(content):
     a tiddler.
     """
     content = _escape_brackets(content)
-    parser = html5lib.HTMLParser(tree=treebuilders.getTreeBuilder('beautifulsoup'))
+    parser = html5lib.HTMLParser(
+            tree=treebuilders.getTreeBuilder('beautifulsoup'))
     soup = parser.parse(content)
     tiddler = soup.find('div')
     return tiddler
@@ -184,11 +194,13 @@ def import_plugin(bag, url, store):
         meta_content = 'title: %s\ntags: systemConfig\n' % default_title
 
     try:
-        title = [line for line in meta_content.split('\n') if line.startswith('title:')][0]
+        title = [line for line in meta_content.split('\n')
+                if line.startswith('title:')][0]
         title = title.split(':', 1)[1].lstrip().rstrip()
     except IndexError:
         title = default_title
-    tiddler_meta = '\n'.join([line for line in meta_content.split('\n') if not line.startswith('title:')])
+    tiddler_meta = '\n'.join([line for line in meta_content.split('\n')
+        if not line.startswith('title:')])
 
     tiddler_meta.rstrip()
     tiddler_text = '%s\n\n%s' % (tiddler_meta, plugin_content)
@@ -204,8 +216,8 @@ def import_plugin(bag, url, store):
 def _escape_brackets(content):
     open_pre = content.index('<pre>')
     close_pre = content.rindex('</pre>')
-    start = content[0:open_pre+5]
-    middle = content[open_pre+5:close_pre]
+    start = content[0:open_pre + 5]
+    middle = content[open_pre + 5:close_pre]
     end = content[close_pre:]
     middle = middle.replace('>', '&gt;').replace('<', '&lt;')
     return start + middle + end
